
from formant.sdk.cloud.v2.formant_admin_api_client.models import DeviceOnlineEventSeverity, DevicePortForwardingConfiguration, DeviceConfiguration, PartialDevice, Device, DeviceCredentials, DeviceConfigurationDocumentTags, DeviceReportedConfigurationState, DeviceTeleopHardwareStreamConfiguration, DeviceStreamFileTailConfigurationType, DeviceStreamHardwareConfigurationQuality, DeviceQuery, KernelInfo, DeviceConfigurationDocument, DeviceStreamFileTailConfiguration, DeviceDiskConfiguration, DeviceDetailsType, TeleopJoystickAxisConfigurationDimension, RtcInfo, DeviceStreamHardwareConfigurationHardwareType, DeviceStreamHardwareConfigurationType, DeviceTeleopCustomStreamConfigurationQuality, OnDemandBufferBufferType, OnDemandStreamPresence, DeviceTeleopCustomStreamConfiguration, DeviceOfflineEvent, PartialDeviceType, DeviceOnlineEvent, NodeInfo, DeviceTeleopCustomStreamConfigurationRtcStreamType, DeviceTeleopHardwareStreamConfigurationQuality, AudioDevice, DeviceStreamConfiguration, TeleopViewConfiguration, DeviceTeleopRosStreamConfigurationAudioCodec, VideoDevice, DeviceOfflineEventStreamType, DeviceTeleopCustomStreamConfigurationNumericControlVisualization, DeviceStreamRosTransformTreeConfiguration, DeviceStreamDirectoryWatchConfigurationFileType, DeviceStreamRosLocalizationConfiguration, DeviceOfflineEventMetadata, DeviceTeleopHardwareStreamConfigurationHardwareType, DeviceStreamRosTransformTreeConfigurationType, DeviceTeleopRosStreamConfigurationNumericControlVisualization, DeviceDetailsListResponse, DeviceType, DeviceConfigurationTemplateListResponse, DeviceRosConfiguration, DeviceProvisioning, DeviceStreamRosTopicConfigurationType, DeviceListResponse, DeviceProvisioningRequest, OnDemandBuffer, DeviceTeleopHardwareStreamConfigurationRtcStreamType, DeviceApplicationConfiguration, DeviceTelemetryConfiguration, OnDemandPresenceTimeRange, DeviceStreamDirectoryWatchConfigurationType, DeviceOfflineEventTags, DeviceBlobData, DeviceConfigurationTemplate, DeviceTeleopRosStreamConfigurationQuality, NetworkInfo, DeviceOfflineEventType, HwInfo, RtcInfoRtcIceTransportPoliciesItem, DeviceOnlineEventMetadata, DeviceStreamHardwareConfiguration, DeviceStreamCustomConfigurationType, DeviceDetailsTags, TeleopJoystickConfigurationPosition, DeviceTeleopCustomStreamConfigurationMode, DeviceStreamConfigurationTags, DeviceStreamFileTailConfigurationFileFormat, DeviceStreamRosTopicConfiguration, DeviceTeleopHardwareStreamConfigurationMode, OnvifDevice, AdapterConfiguration, DeviceApplicationConfigurationConfigurationMap, DeviceOnlineEventType, DeviceTeleopConfiguration, OnDemandState, DeviceOnlineEventStreamType, DeviceStreamRosLocalizationConfigurationType, DeviceOfflineEventSeverity, ScopeFilterTypesItem, DeviceDetails, ValidationConfiguration, Network, ScopeFilter, PartialDeviceTags, TeleopJoystickAxisConfiguration, DeviceStreamCustomConfiguration, DeviceTags, DeviceStreamTransformConfiguration, OsInfo, DeviceDiagnosticsConfiguration, DeviceState, DeviceRosState, DeviceTeleopRosStreamConfigurationMode, DeviceStreamConfigurationQuality, DeviceScope, CommandProgress, OnDemandPresenceStreamItemGroupDatapointType, DeviceFollower, DeviceResourcesConfiguration, OnDemandPresenceStreamItemGroup, TeleopJoystickConfiguration, DeviceTeleopRosStreamConfigurationTopicType, DeviceScopeTypesItem, DeviceStreamDirectoryWatchConfiguration, RosTopic, DeviceTeleopRosStreamConfiguration, DeviceOnlineEventTags, DeviceStateEnv, DeviceQueryType, DeviceConfigurationTemplateTags, RtcInfoRtcIceServerProtocol
from formant.sdk.cloud.v2.formant_admin_api_client.api.device import device_controller_query, device_controller_patch, device_controller_get_one, device_controller_get_configuration, device_controller_post_configuration
from formant.sdk.cloud.v2.formant_admin_api_client.types import *
from formant.sdk.cloud.v2.formant_admin_api_client.types import Optional
